@@ -754,33 +754,31 @@ class Telescope : public DefaultDevice
         */
 
         // All telescopes should produce equatorial co-ordinates
-        INumberVectorProperty EqNP;
-        INumber EqN[2];
+        INDI::PropertyNumber EqNP {2};
 
         // When a goto is issued, domes will snoop the target property
         // to start moving the dome when a telescope moves
-        INumberVectorProperty TargetNP;
-        INumber TargetN[2];
+        INDI::PropertyNumber TargetNP {2};
 
         // Abort motion
-        ISwitchVectorProperty AbortSP;
-        ISwitch AbortS[1];
+        INDI::PropertySwitch AbortSP {1};
 
         // On a coord_set message, sync, or slew
-        ISwitchVectorProperty CoordSP;
-        ISwitch CoordS[4];
+        INDI::PropertySwitch CoordSP {4};
 
         // A number vector that stores latitude and longitude
-        INumberVectorProperty LocationNP;
-        INumber LocationN[3];
+        INDI::PropertyNumber LocationNP {3};
 
         // A Switch in the client interface to park the scope
-        ISwitchVectorProperty ParkSP;
-        ISwitch ParkS[2];
+        INDI::PropertySwitch ParkSP {2};
+        enum
+        {
+            PARK,
+            UNPARK
+        };
 
         // Custom parking position
-        INumber ParkPositionN[2];
-        INumberVectorProperty ParkPositionNP;
+        INDI::PropertyNumber ParkPositionNP {2};
 
         /**
         + NAME: TELESCOPE_PARK_POSITION
@@ -803,12 +801,10 @@ class Telescope : public DefaultDevice
         };
 
         // A switch for North/South motion
-        ISwitch MovementNSS[2];
-        ISwitchVectorProperty MovementNSSP;
+        INDI::PropertySwitch MovementNSSP {2};
 
         // A switch for West/East motion
-        ISwitch MovementWES[2];
-        ISwitchVectorProperty MovementWESP;
+        INDI::PropertySwitch MovementWESP {2};
 
         // Reverse NS or WE
         INDI::PropertySwitch ReverseMovementSP {2};
@@ -819,12 +815,15 @@ class Telescope : public DefaultDevice
         };
 
         // Slew Rate
-        ISwitchVectorProperty SlewRateSP;
-        ISwitch *SlewRateS {nullptr};
+        INDI::PropertySwitch SlewRateSP {0};
 
         // UTC and UTC Offset
-        IText TimeT[2] {};
-        ITextVectorProperty TimeTP;
+        INDI::PropertyText TimeTP {2};
+        enum
+        {
+            UTC,
+            OFFSET
+        };
         void sendTimeFromSystem();
 
         // Active GPS/Dome device to snoop
@@ -836,29 +835,33 @@ class Telescope : public DefaultDevice
         };
 
         // Switch to lock if dome is closed.
-        ISwitchVectorProperty DomePolicySP;
-        ISwitch DomePolicyS[2];
+        INDI::PropertySwitch DomePolicySP {2};
 
         // Switch for choosing between motion control by 4-way joystick or two separate axes
-        ISwitchVectorProperty MotionControlModeTP;
-        ISwitch MotionControlModeT[2];
+        INDI::PropertySwitch MotionControlModeTP {2};
         enum
         {
-            MOTION_CONTROL_JOYSTICK,
-            MOTION_CONTROL_AXES
+            MOTION_CONTROL_MODE_JOYSTICK,
+            MOTION_CONTROL_MODE_AXES,
         };
 
         // Lock Joystick Axis to one direction only
-        ISwitch LockAxisS[2];
-        ISwitchVectorProperty LockAxisSP;
-
+        INDI::PropertySwitch LockAxisSP {2};
+        enum
+        {
+            LOCK_AXIS_1,
+            LOCK_AXIS_2
+        };
         // Pier Side
-        ISwitch PierSideS[2];
-        ISwitchVectorProperty PierSideSP;
+        INDI::PropertySwitch PierSideSP {2};
 
         // Pier Side Simulation
-        ISwitchVectorProperty SimulatePierSideSP;
-        ISwitch SimulatePierSideS[2];
+        INDI::PropertySwitch SimulatePierSideSP {2};
+        enum
+        {
+            SIMULATE_YES,
+            SIMULATE_NO
+        };
         bool getSimulatePierSide() const;
         void setSimulatePierSide(bool value);
 
@@ -872,8 +875,7 @@ class Telescope : public DefaultDevice
          * \brief Text Vector property defining the orbital elements of an artificial satellite (TLE).
          * \ref drivers/telescope/lx200_10micron.cpp "Example implementation"
          */
-        ITextVectorProperty TLEtoTrackTP;
-        IText TLEtoTrackT[1] {};
+        INDI::PropertyText TLEtoTrackTP{1};
         /**
          * \struct SatelliteWindow
          * \brief Satellite pass: window start and end.
@@ -888,8 +890,7 @@ class Telescope : public DefaultDevice
          * \brief Text Vector property defining the start and end of a satellite pass (window contains pass).
          * \ref drivers/telescope/lx200_10micron.cpp "Example implementation"
          */
-        ITextVectorProperty SatPassWindowTP;
-        IText SatPassWindowT[SAT_PASS_WINDOW_COUNT] {};
+        INDI::PropertyText SatPassWindowTP {0};
         /**
          * \struct SatelliteTracking
          * \brief Possible states for the satellite tracking.
@@ -904,24 +905,20 @@ class Telescope : public DefaultDevice
          * \brief Switch Vector property defining the state of the satellite tracking of the mount.
          * \ref drivers/telescope/lx200_10micron.cpp "Example implementation"
          */
-        ISwitchVectorProperty TrackSatSP;
-        ISwitch TrackSatS[SAT_TRACK_COUNT];
+        INDI::PropertySwitch TrackSatSP {0};
 
         // PEC State
-        ISwitch PECStateS[2];
-        ISwitchVectorProperty PECStateSP;
+        INDI::PropertySwitch PECStateSP {2};
 
         // Track Mode
-        ISwitchVectorProperty TrackModeSP;
-        ISwitch *TrackModeS { nullptr };
+        INDI::PropertySwitch TrackModeSP {0};
 
         // Track State
-        ISwitchVectorProperty TrackStateSP;
-        ISwitch TrackStateS[2];
+        INDI::PropertySwitch TrackStateSP {2};
+        // ISwitch TrackStateS[2];
 
         // Track Rate
-        INumberVectorProperty TrackRateNP;
-        INumber TrackRateN[2];
+        INDI::PropertyNumber TrackRateNP {2};
 
         // Home Position
         INDI::PropertySwitch HomeSP {0};
